# Credentials
A simple environment-aware wrapper around Rails encrypted credentials.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'ez-credentials', require 'credentials'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install ez-credentials

## Usage
This gem assumes you are in a rails application and are using one encrypted credential file with environmnet namespaces, like the example below:

```yml
development:
  foo:
    bar: baz
test:
  foo:
    bar: test-baz
staging:
  foo:
    bar: staging-baz
production:
  foo:
    bar: realsecret
```

The `Credentials` class wraps `Rails.application.credentials` call with environment-aware easy accessors.
To access credentials in the project for the correct environment, use one of the methods below:
```ruby
require 'credentials' # if not required in Gemfile

Credentials.all
# => {:foo => {:bar => 'baz'}}

Credentials.get(:foo) # also takes string 'foo'
# => {:bar=>"baz"}

Credentials.get('foo.bar')
# => "baz"

Credentials.get(:foo, :bar)
# => "baz"
```

---

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and the created tag, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on BitBucket at https://bitbucket.org/eightbitdevelopers/credentials.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
